package celular;

/**
 * Universidade Federal de Pernambuco
 * Centro de Informtica
 * Disciplina: Introducao a Programao
 * Projeto Celular
 *
 * Tipo: PrevisaoTexto
 *
 * @author: Alberto Csar C. Frana     (accf2@cin.ufpe.br)
 * @author: Luciana Pereira Oliveira    (lpo@cin.ufpe.br)
 * @author: Milena Rocha Leite          (mrl@cin.ufpe.br)    
 *
 * @since 2002
 * @version 1.0
 */

import celular.palavras.CadastroPalavras;
import celular.palavras.ListaPalavras;
import celular.palavras.Palavra;
import celular.util.Console;



public class PrevisaoTexto implements IPrevisaoTexto {

	private CadastroPalavras vocabulario;

/**
 * Construtor da classe
 *
 */
public PrevisaoTexto(){
	this.vocabulario = new CadastroPalavras(new ListaPalavras());
}
/**
 * Construtor da classe
 *
 * @param CadastroPalavras valor inicial para o cadastro
 */
public PrevisaoTexto(CadastroPalavras cadastro){
	
	if(cadastro != null){
		this.vocabulario = cadastro;
	} else{
		new Console().println("ERRO: O Cadastro passado nao eh valido");		
	}		
}
/**
 * Mtodo que exclui um palavra do dicionario
 *
 * @param Palavra  palavra a ser excluida do dicionario
 */
public void excluir(Palavra palavra){
	if(palavra != null){
		vocabulario.excluir(palavra);
	} else {
		new Console().println("ERRO: A palavra  passada estah nula");				
	}		
}      
/**
 * Mtodo que verifica se uma palavra existe no dicionario
 *
 * @param  Palavra  palavra a ser procurada
 *
 * @return boolean  indica se a palvra existe ou nao
 */
public boolean existe(Palavra palavra) {
	boolean retorno = false;

	if(palavra != null){
		retorno = vocabulario.existe(palavra);
	} else {
		new Console().println("ERRO: A palavra passada estah nula");				
	}		
	return retorno;
}      
/**
 * Mtodo que retorna todas as palavras do dicionario que possuem uma das
 * letras passadas da posicao indicada
 *
 * @param  char[]         characteres a serem verificados
 * @return ListaPalavras  lista de palavras que possuem um dos caracteres
 *                          passados
 */
public ListaPalavras filtrar(char[] letras,int posicaoAtual){
	return vocabulario.filtrar(letras,posicaoAtual);
}         
/**
 * Mtodo que insere uma palavra na colecao
 *
 * @param Palvra   plavra a ser inserida
 */
public void inserir(Palavra palavra) {

	if(palavra != null){
		vocabulario.inserir(palavra);
	} else {
		new Console().println("ERRO: A palavra passada estah nula");				
	}			
	
}      
}
