package celular.palavras;

/**
  * Universidade Federal de Pernambuco
  * Centro de Informtica
  * Disciplina: Introducao a Programao
  * Projeto Celular
  *
  * Tipo: CadastroPalavras
  *
  * @author: Alberto Csar C. Frana     (accf2@cin.ufpe.br)
  * @author: Luciana Pereira Oliveira    (lpo@cin.ufpe.br)
  * @author: Milena Rocha Leite          (mrl@cin.ufpe.br)    
  *
  * @since 2002
  * @version 1.0
  **/

import celular.util.Console;

public class CadastroPalavras {
  private ListaPalavras palavras;

/**
 * Construtor da classe
 *
 * @param ListaPalavras valor inicial para a lista de palavras
 */
public CadastroPalavras(ListaPalavras l) {
	if (l != null) {
		palavras = l;
	} else {
	  new Console().println("ERRO: A lista passada como parametro nao eh valida");
	}
}      
/**
 * Mtodo que exclui um palavra do dicionario
 *
 * @param Palavra  palavra a ser excluida do dicionario
 */
public void excluir(Palavra palavra) {
	if (palavra != null){
		this.palavras.excluir(palavra);
	} else {
		new Console().println("ERRO: A palavra passada como parametro nao eh valida");
	}
}      
/**
 * Mtodo que verifica se uma palavra existe no dicionario
 *
 * @param  Palavra  palavra a ser procurada
 *
 * @return boolean  indica se a palvra existe ou nao
 */
public boolean existe(Palavra palavra) {
	boolean retorno = false;

	if(palavra != null){
		retorno = this.palavras.existe(palavra);
	} else {
		new Console().println("ERRO: A palavra passada estah nula");				
	}		
	return retorno;
	
}      
/**
 * Mtodo que retorna todas as palavras do dicionario que possuem uma das
 * letras passadas da posicao indicada
 *
 * @param  char[]         characteres a serem verificados
 * @return ListaPalavras  lista de palavras que possuem um dos caracteres
 *                          passados
 */
public ListaPalavras filtrar(char[] letras,int posicaoAtual){
	return palavras.filtrar(letras,posicaoAtual);
}         
/**
 * Mtodo que insere uma palavra na colecao
 *
 * @param Palvra   plavra a ser inserida
 */
public void inserir(Palavra palavra) {
	  if (palavra != null){
		if (!palavras.existe(palavra))  {
		   this.palavras.inserir(palavra);
		} else {
			new Console().println("ERRO: a palavra jah existe!");
		}
	  } else {
		new Console().println("ERRO: A palavra passada como parametro nao eh valida");
	  }
   }         
	//main para verificacao de alguns metodos
	public static void main(String args[]){
	  Console c = new Console();
	  CadastroPalavras  r = new CadastroPalavras(new ListaPalavras());
	  ListaPalavras temp;
		r.inserir(new Palavra("bola"));
	  r.inserir(new Palavra("bolada"));
		r.inserir(new Palavra("bolo"));
		r.inserir(new Palavra("dado"));
		r.inserir(new Palavra("dedo"));
	  r.inserir(null);
		c.println("Existe bolo : " + r.existe(new Palavra("bolo")));

		c.println("\nPalavras Existentes:");

	  r.reset();
	  Palavra p = r.proxima();
	  while(p != null){
		  c.println(p.getPalavra());
		  p = r.proxima();
		}

	  r.excluir(new Palavra("bolo"));
		c.println("\nExiste bolo : " + r.existe(new Palavra("bolo")));
	  r.excluir(null);
	  char[] letras = {'a','b','c'};
	  r = new CadastroPalavras(r.filtrar(letras,1));
	  r.reset();
	  p = r.proxima();
	  while(p != null){
	  		c.println(p.getPalavra());
		  p = r.proxima();
		}
	  //c.readString();
	}
/**
 * Mtodo que retorna a prxima palavra da lista
 *
 * @return Palavra proxima palavra da lista
 */
public Palavra proxima() {
	return this.palavras.proxima();
}    
/**
 * Mtodo que faz a lista voltar pro comeco
 */
public void reset() {
	this.palavras.reset();
}    
}
