package celular.palavras;

/**
  * Universidade Federal de Pernambuco
  * Centro de Informtica
  * Disciplina: Introducao a Programao
  * Projeto Celular
  *
  * Tipo: ListaPalavras
  *
  * @author: Alberto Csar C. Frana     (accf2@cin.ufpe.br)
  * @author: Luciana Pereira Oliveira    (lpo@cin.ufpe.br)
  * @author: Milena Rocha                (mrl@cin.ufpe.br)    
  *
  * @since 2002
  * @version 1.0
  **/

import celular.util.Console;

public class ListaPalavras {

  private Palavra[] elementos;
  private int proxima;  //indica o proximo indice que pode receber um objeto
  private int maximo;  //indica o tamanho maximo do array de objetos

  private final static byte NAO_EXISTE = -1;
  private final static int TAMANHO_MAXIMO_INICIAL = 5;

  private int indiceParaIteracao;

 /**
  * Construtor da classe 
  */
  public ListaPalavras() {
	 this.reset();
	 maximo = TAMANHO_MAXIMO_INICIAL;
	 elementos = new Palavra[maximo];
	 proxima = 0;
  }      
   /**
	* Mtodo que duplica o tamanho do array quando necessario
	* para evitar o estouro do mesmo
	*
	*/
   private void duplicarTamanho() {
	   
	 Palavra[] temp = new Palavra[this.maximo * 2];
	 for (int i = 0; i < this.maximo; i = i + 1) {
	   temp[i] = this.elementos[i];
	 }
	 this.elementos = temp;
	 this.maximo = this.maximo * 2;
   }         
/**
 * Mtodo que exclui um palavra do dicionario
 *
 * @param Palavra  palavra a ser excluida do dicionario
 */
public void excluir(Palavra palavra) {
 	int posicao;
 	 
	if (palavra != null){
		posicao = this.posicao(palavra);
	if (posicao == NAO_EXISTE) {
	   new Console().println("ERRO: A palavra nao existe!!");
	} else {
		elementos[posicao] = null;
		elementos[posicao] = elementos[proxima - 1];
		elementos[proxima - 1] = null;
		proxima = proxima - 1;
		new Console().println("!!A palavra foi removida com sucesso!!");
	}
  }
}
/**
 * Mtodo que verifica se uma palavra existe no dicionario
 *
 * @param  Palavra  palavra a ser procurada
 *
 * @return boolean  indica se a palvra existe ou nao
 */
public boolean existe(Palavra chave) {
	boolean resposta = false;
 	if (chave != null){
		if (this.posicao(chave) == NAO_EXISTE) {
			resposta = false;
		 } else {
			resposta = true;
		 }
	 }
	 return resposta;
}    
/**
 * Mtodo que retorna todas as palavras do dicionario que possuem uma das
 * letras passadas da posicao indicada
 *
 * @param  char[]         characteres a serem verificados
 * @return ListaPalavras  lista de palavras que possuem um dos caracteres
 *                          passados
 */
public ListaPalavras filtrar(char[] letras,int posicaoAtual){
	ListaPalavras temp = new ListaPalavras();
	
	Palavra palavra;
	for (int i = 0 ; i < proxima; i++){
	  palavra = elementos[i];
	  if(palavra.temLetras(letras,posicaoAtual)){
		temp.inserir(palavra);
	  }
	}
	return temp;
  }          
/**
 * Mtodo retorna o tamanho da lista, ou seja, valor do atributo 
 * proxima que indica a proxima posicao livre do array
 *
 * @return int representa o tamanho da lista
 */
public int getTamanho() {
	return proxima;
}
/**
 * Mtodo que insere uma palavra na colecao
 *
 * @param Palvra   plavra a ser inserida
 */
public void inserir(Palavra palavra) {
	 if (palavra != null){
		  if (this.proxima == this.maximo) {
			  this.duplicarTamanho();
		  }
		  this.elementos[proxima] = palavra;
		  this.proxima = this.proxima + 1;
	  } else {
		  new Console().println("ERRO: a palavra nao eh valida!");
	}
}      
  //main para verificacao de alguns metodos
  public static void main(String args[]) {
	Console c = new Console();
	Palavra p1,p2,p3,p4,p6,p5;
	p1 = new Palavra("casa");
	ListaPalavras lista = new ListaPalavras();
	lista.inserir(p1);
	p2 = new Palavra("carro");
	lista.inserir(p2);
	p3 = new Palavra("estrada");
	lista.inserir(p3);
	p4 = new Palavra("onda");
	lista.inserir(p4);
	p5 = new Palavra("roda");
	lista.inserir(p5);
	p6 = new Palavra("praia");
	lista.inserir(p6);
	c.println("tam" +lista.getTamanho());
	c.println("get 0"+ (lista.proxima()).getPalavra());
	lista.excluir(p4);
	c.println("tam: "+lista.getTamanho());
	lista.reset();
	c.println("get 0!!!"+ (lista.proxima()).getPalavra());
	c.println("Verifica se existe casa "+lista.existe(new Palavra("casa")));
	c.println("Verifica se existe mm "+lista.existe(new Palavra("mm")));
	c.println("Verifica posica de casa "+lista.posicao(new Palavra("casa")));
  }        
/**
 * Mtodo que retorna a posicao de uma palavra na colecao
 *
 * @param Palavra    palavra a ser procurada
 * @return int       que indica a posicao da palavra procurada
 */
private int posicao(Palavra chave) {
	int i = 0;
	boolean achou = false;
	if (chave != null){
		while(!achou && i < proxima) {
		  if (chave.equals(this.elementos[i])) {
				   achou = true;
		  } else {
			  i = i + 1;
		  }
		}
		if (!achou) {
		   i = NAO_EXISTE;
		}
	} else {
		i = NAO_EXISTE;
	}

	return i;
}    
/**
 * Mtodo que retorna a prxima palavra da lista
 *
 * @return Palavra proxima palavra da lista
 */
public Palavra proxima(){
	Palavra retorno = null;

	if (indiceParaIteracao < proxima) {
	  retorno = elementos[indiceParaIteracao];
	  indiceParaIteracao = indiceParaIteracao + 1;
	}
	return retorno;
}    
/**
 * Mtodo que faz a lista voltar pro comeco
 */
public void reset(){
	this.indiceParaIteracao = 0;
}    
}
